:orphan:

.. Orphan tag suppresses 'WARNING: document isn't included in any toctree',
   remove when document will be updated.

.. _sec-user_guide-atmosphere:

Atmosphere guide
================

.. toctree::
   intro
   homogeneous
   heterogeneous
   molecular
   particle_layer
   absorption
   rayleigh_scattering
